@@ -1,4 +1,4 @@
-# Copyright 2022 Avaiga Private Limited
+# Copyright 2023 Avaiga Private Limited
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 # the License. You may obtain a copy of the License at
@@ -21,6 +21,7 @@ from taipy.config.config import Config
 from taipy.logger._taipy_logger import _TaipyLogger
 
 from ..common.alias import JobId
+from ..data import CSVDataNode, DataNode, ExcelDataNode, JSONDataNode, ParquetDataNode, PickleDataNode
 from ..data._data_manager_factory import _DataManagerFactory
 from ..job._job_manager_factory import _JobManagerFactory
 from ..job.job import Job
@@ -62,8 +63,10 @@ class _Scheduler(_AbstractScheduler):
              callbacks: The optional list of functions that should be executed on jobs status change.
              force (bool) : Enforce execution of the pipeline's tasks even if their output data
                 nodes are cached.
-             wait (bool): Wait for the scheduled jobs created from the pipeline submission to be finished in asynchronous mode.
-             timeout (Union[float, int]): The optional maximum number of seconds to wait for the jobs to be finished before returning.
+             wait (bool): Wait for the scheduled jobs created from the pipeline submission to be finished in
+                asynchronous mode.
+             timeout (Union[float, int]): The optional maximum number of seconds to wait for the jobs to be finished
+                before returning.
         Returns:
             The created Jobs.
         """
@@ -76,7 +79,7 @@ class _Scheduler(_AbstractScheduler):
                     res.append(cls._submit_task(task, submit_id, callbacks=callbacks, force=force))
 
         if Config.job_config.is_development:
-            cls.__check_and_execute_jobs_if_development_mode()
+            cls._check_and_execute_jobs_if_development_mode()
         else:
             if wait:
                 cls.__wait_until_job_finished(res, timeout=timeout)
@@ -99,8 +102,10 @@ class _Scheduler(_AbstractScheduler):
              submit_id (str): The optional id to differentiate each submission.
              callbacks: The optional list of functions that should be executed on job status change.
              force (bool): Enforce execution of the task even if its output data nodes are cached.
-             wait (bool): Wait for the scheduled job created from the task submission to be finished in asynchronous mode.
-             timeout (Union[float, int]): The optional maximum number of seconds to wait for the job to be finished before returning.
+             wait (bool): Wait for the scheduled job created from the task submission to be finished in asynchronous
+                mode.
+             timeout (Union[float, int]): The optional maximum number of seconds to wait for the job to be finished
+                before returning.
         Returns:
             The created `Job^`.
         """
@@ -108,7 +113,7 @@ class _Scheduler(_AbstractScheduler):
             job = cls._submit_task(task, submit_id, callbacks, force)
 
         if Config.job_config.is_development:
-            cls.__check_and_execute_jobs_if_development_mode()
+            cls._check_and_execute_jobs_if_development_mode()
         else:
             if wait:
                 cls.__wait_until_job_finished(job, timeout=timeout)
@@ -167,8 +172,8 @@ class _Scheduler(_AbstractScheduler):
             except Exception:
                 pass
 
-    @staticmethod
-    def _is_blocked(obj: Union[Task, Job]) -> bool:
+    @classmethod
+    def _is_blocked(cls, obj: Union[Task, Job]) -> bool:
         """Returns True if the execution of the `Job^` or the `Task^` is blocked by the execution of another `Job^`.
 
         Parameters:
@@ -177,16 +182,35 @@ class _Scheduler(_AbstractScheduler):
         Returns:
              True if one of its input data nodes is blocked.
         """
+
         data_nodes = obj.task.input.values() if isinstance(obj, Job) else obj.input.values()
         data_manager = _DataManagerFactory._build_manager()
-        return any(not data_manager._get(dn.id).is_ready_for_reading for dn in data_nodes)
+
+        def get_dn_is_ready_for_reading(dn: DataNode):
+            dn = data_manager._get(dn.id)
+            if dn.is_ready_for_reading is False and not dn._last_edit_date:
+                if dn.storage_type() in [
+                    CSVDataNode.storage_type(),
+                    ExcelDataNode.storage_type(),
+                    JSONDataNode.storage_type(),
+                    PickleDataNode.storage_type(),
+                    ParquetDataNode.storage_type(),
+                ]:
+                    cls.__logger.warning(
+                        f"{dn.id} cannot be read because it has never been written. Hint: The data node may refer to "
+                        f"a wrong path : {dn.path} "
+                    )
+                else:
+                    cls.__logger.warning(f"{dn.id} cannot be read because it has never been written.")
+            return dn.is_ready_for_reading
+
+        return any(not get_dn_is_ready_for_reading(dn) for dn in data_nodes)
 
     @staticmethod
-    def _unlock_edit_on_outputs(jobs: Union[Job, List[Job], Set[Job]]):
+    def _unlock_edit_on_jobs_outputs(jobs: Union[Job, List[Job], Set[Job]]):
         jobs = [jobs] if isinstance(jobs, Job) else jobs
         for job in jobs:
-            for dn in job.task.output.values():
-                dn.unlock_edit()
+            job._unlock_edit_on_outputs()
 
     @classmethod
     def _on_status_change(cls, job: Job):
@@ -226,7 +250,7 @@ class _Scheduler(_AbstractScheduler):
                 cls.__remove_blocked_jobs(to_cancel_or_abandon_jobs)
                 cls.__remove_jobs_to_run(to_cancel_or_abandon_jobs)
                 cls._cancel_jobs(job.id, to_cancel_or_abandon_jobs)
-                cls._unlock_edit_on_outputs(to_cancel_or_abandon_jobs)
+                cls._unlock_edit_on_jobs_outputs(to_cancel_or_abandon_jobs)
 
     @classmethod
     def __find_subsequent_jobs(cls, submit_id, output_dn_config_ids: Set) -> Set[Job]:
@@ -269,7 +293,7 @@ class _Scheduler(_AbstractScheduler):
             to_fail_or_abandon_jobs.update([failed_job])
             cls.__remove_blocked_jobs(to_fail_or_abandon_jobs)
             cls.__remove_jobs_to_run(to_fail_or_abandon_jobs)
-            cls._unlock_edit_on_outputs(to_fail_or_abandon_jobs)
+            cls._unlock_edit_on_jobs_outputs(to_fail_or_abandon_jobs)
 
     @classmethod
     def _cancel_jobs(cls, job_id_to_cancel: JobId, jobs: Set[Job]):
@@ -289,8 +313,8 @@ class _Scheduler(_AbstractScheduler):
                     job.abandoned()
 
     @staticmethod
-    def __check_and_execute_jobs_if_development_mode():
-
+    def _check_and_execute_jobs_if_development_mode():
         from ._scheduler_factory import _SchedulerFactory
 
-        _SchedulerFactory._build_dispatcher()._execute_jobs_synchronously()
+        if dispatcher := _SchedulerFactory._dispatcher:
+            dispatcher._execute_jobs_synchronously()
