@@ -1,4 +1,4 @@
-# Copyright 2022 Avaiga Private Limited
+# Copyright 2023 Avaiga Private Limited
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 # the License. You may obtain a copy of the License at
@@ -11,9 +11,10 @@
 
 from typing import Type
 
-from ._data_manager import _DataManager
 from .._manager._manager_factory import _ManagerFactory
 from ..common._utils import _load_fct
+from ._data_manager import _DataManager
+from ._data_repository_factory import _DataRepositoryFactory
 
 
 class _DataManagerFactory(_ManagerFactory):
@@ -21,4 +22,5 @@ class _DataManagerFactory(_ManagerFactory):
     def _build_manager(cls) -> Type[_DataManager]:  # type: ignore
         if cls._using_enterprise():
             return _load_fct(cls._TAIPY_ENTERPRISE_CORE_MODULE + ".data._data_manager", "_DataManager")  # type: ignore
+        _DataManager._repository = _DataRepositoryFactory._build_repository()  # type: ignore
         return _DataManager
