@@ -1,4 +1,4 @@
-# Copyright 2022 Avaiga Private Limited
+# Copyright 2023 Avaiga Private Limited
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 # the License. You may obtain a copy of the License at
@@ -11,14 +11,18 @@
 
 from typing import Type
 
-from ._pipeline_manager import _PipelineManager
 from .._manager._manager_factory import _ManagerFactory
 from ..common._utils import _load_fct
+from ._pipeline_manager import _PipelineManager
+from ._pipeline_repository_factory import _PipelineRepositoryFactory
 
 
 class _PipelineManagerFactory(_ManagerFactory):
     @classmethod
     def _build_manager(cls) -> Type[_PipelineManager]:  # type: ignore
         if cls._using_enterprise():
-            return _load_fct(cls._TAIPY_ENTERPRISE_CORE_MODULE + ".pipeline._pipeline_manager", "_PipelineManager")  # type: ignore
+            return _load_fct(
+                cls._TAIPY_ENTERPRISE_CORE_MODULE + ".pipeline._pipeline_manager", "_PipelineManager"
+            )  # type: ignore
+        _PipelineManager._repository = _PipelineRepositoryFactory._build_repository()  # type: ignore
         return _PipelineManager
