@@ -1,4 +1,4 @@
-# Copyright 2022 Avaiga Private Limited
+# Copyright 2023 Avaiga Private Limited
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 # the License. You may obtain a copy of the License at
@@ -13,18 +13,20 @@ import dataclasses
 from dataclasses import dataclass
 from typing import Any, Dict, List, Optional
 
+from .._version._utils import _version_migration
 from ..common.alias import PipelineId, TaskId
 
 
 @dataclass
 class _PipelineModel:
-
     id: PipelineId
-    parent_id: Optional[str]
+    owner_id: Optional[str]
+    parent_ids: List[str]
     config_id: str
     properties: Dict[str, Any]
     tasks: List[TaskId]
     subscribers: List[Dict]
+    version: str
 
     def to_dict(self) -> Dict[str, Any]:
         return dataclasses.asdict(self)
@@ -34,8 +36,10 @@ class _PipelineModel:
         return _PipelineModel(
             id=data["id"],
             config_id=data["config_id"],
-            parent_id=data["parent_id"],
+            owner_id=data.get("owner_id", data.get("parent_id")),
+            parent_ids=data.get("parent_ids", []),
             properties=data["properties"],
             tasks=data["tasks"],
             subscribers=data["subscribers"],
+            version=data["version"] if "version" in data.keys() else _version_migration(),
         )
