@@ -1,4 +1,4 @@
-# Copyright 2022 Avaiga Private Limited
+# Copyright 2023 Avaiga Private Limited
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 # the License. You may obtain a copy of the License at
@@ -11,6 +11,7 @@
 
 from __future__ import annotations
 
+import pathlib
 import uuid
 from datetime import datetime
 from typing import Any, Callable, Dict, List, Optional, Set, Union
@@ -18,6 +19,7 @@ from typing import Any, Callable, Dict, List, Optional, Set, Union
 from taipy.config.common._template_handler import _TemplateHandler as _tpl
 from taipy.config.common._validate_id import _validate_id
 
+from .._version._version_manager_factory import _VersionManagerFactory
 from ..common._entity import _Entity
 from ..common._listattributes import _ListAttributes
 from ..common._properties import _Properties
@@ -48,6 +50,8 @@ class Scenario(_Entity):
         cycle (Cycle^): The cycle of the scenario.
         subscribers (Set[Callable]): The set of callbacks to be called on `Job^`'s status change.
         tags (Set[str]): The list of scenario's tags.
+        version (str): The string indicates the application version of the scenario to instantiate. If not provided,
+            the latest version is used.
     """
 
     _ID_PREFIX = "SCENARIO"
@@ -65,6 +69,7 @@ class Scenario(_Entity):
         cycle: Cycle = None,
         subscribers: List[_Subscriber] = None,
         tags: Set[str] = None,
+        version: str = None,
     ):
         self.config_id = _validate_id(config_id)
         self.id: ScenarioId = scenario_id or self._new_id(self.config_id)
@@ -74,6 +79,7 @@ class Scenario(_Entity):
         self._subscribers = _ListAttributes(self, subscribers or list())
         self._primary_scenario = is_primary
         self._tags = tags or set()
+        self._version = version or _VersionManagerFactory._build_manager()._get_latest_version()
 
         self._properties = _Properties(self, **properties)
 
@@ -86,6 +92,9 @@ class Scenario(_Entity):
         sc = tp.get(id)
         self.__dict__ = sc.__dict__
 
+    def __hash__(self):
+        return hash(self.id)
+
     @property  # type: ignore
     @_self_reload(_MANAGER_NAME)
     def pipelines(self):
@@ -155,6 +164,10 @@ class Scenario(_Entity):
     def tags(self, val):
         self._tags = val or set()
 
+    @property  # type: ignore
+    def version(self):
+        return self._version
+
     @property  # type: ignore
     def properties(self):
         self._properties = _reload(self._MANAGER_NAME, self)._properties
@@ -210,7 +223,7 @@ class Scenario(_Entity):
         Parameters:
             tag (str): The tag to search among the set of scenario's tags.
         Returns:
-            bool: True if the scenario has the tag given as parameter. False otherwise.
+            True if the scenario has the tag given as parameter. False otherwise.
         """
         return tag in self.tags
 
@@ -269,13 +282,28 @@ class Scenario(_Entity):
 
         Parameters:
             force (bool): Force execution even if the data nodes are in cache.
-            wait (bool): Wait for the scheduled jobs created from the scenario submission to be finished in asynchronous mode.
-            timeout (Union[float, int]): The optional maximum number of seconds to wait for the jobs to be finished before returning.
+            wait (bool): Wait for the scheduled jobs created from the scenario submission to be finished in
+                asynchronous mode.
+            timeout (Union[float, int]): The optional maximum number of seconds to wait for the jobs to be finished
+                before returning.
         """
         from ... import core as tp
 
         return tp.submit(self, force, wait, timeout)
 
+    def export(
+        self,
+        folder_path: Union[str, pathlib.Path],
+    ):
+        """Export all related entities of this scenario to a folder.
+
+        Parameters:
+            folder_path (Union[str, pathlib.Path]): The folder path to export the scenario to.
+        """
+        from ... import core as tp
+
+        return tp.export_scenario(self.id, folder_path)
+
     def set_primary(self):
         """Promote the scenario as the primary scenario of its cycle.
 
