@@ -1,4 +1,4 @@
-# Copyright 2022 Avaiga Private Limited
+# Copyright 2023 Avaiga Private Limited
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 # the License. You may obtain a copy of the License at
@@ -9,12 +9,17 @@
 # an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
 # specific language governing permissions and limitations under the License.
 
+import pathlib
+import shutil
 from datetime import datetime
-from typing import Any, Callable, Dict, List, Optional, Union
+from typing import Any, Callable, Dict, List, Optional, Set, Union
 
 from taipy.config.config import Config
 from taipy.logger._taipy_logger import _TaipyLogger
 
+from ._version._version_manager_factory import _VersionManagerFactory
+from .common._entity import _Entity
+from .common._warnings import _warn_no_core_service
 from .common.alias import CycleId, DataNodeId, JobId, PipelineId, ScenarioId, TaskId
 from .config.pipeline_config import PipelineConfig
 from .config.scenario_config import ScenarioConfig
@@ -22,7 +27,7 @@ from .cycle._cycle_manager_factory import _CycleManagerFactory
 from .cycle.cycle import Cycle
 from .data._data_manager_factory import _DataManagerFactory
 from .data.data_node import DataNode
-from .exceptions.exceptions import ModelNotFound
+from .exceptions.exceptions import ModelNotFound, NonExistingVersion, VersionIsNotProductionVersion
 from .job._job_manager_factory import _JobManagerFactory
 from .job.job import Job
 from .pipeline._pipeline_manager_factory import _PipelineManagerFactory
@@ -54,6 +59,7 @@ def set(entity: Union[DataNode, Task, Pipeline, Scenario, Cycle]):
         return _DataManagerFactory._build_manager()._set(entity)
 
 
+@_warn_no_core_service()
 def submit(
     entity: Union[Scenario, Pipeline, Task],
     force: bool = False,
@@ -69,7 +75,8 @@ def submit(
         entity (Union[Scenario^, Pipeline^, Task^]): The entity to submit.
         force (bool): If True, the execution is forced even if the data nodes are in cache.
         wait (bool): Wait for the scheduled jobs created from the submission to be finished in asynchronous mode.
-        timeout (Union[float, int]): The optional maximum number of seconds to wait for the jobs to be finished before returning.
+        timeout (Union[float, int]): The optional maximum number of seconds to wait for the jobs to be finished before
+            returning.
 
     """
     if isinstance(entity, Scenario):
@@ -91,8 +98,7 @@ def get(
             It must match the identifier pattern of one of the entities (`Task^`, `DataNode^`,
             `Pipeline^` or `Scenario^`).
     Returns:
-        Union[Task^, DataNode^, Pipeline^, Scenario^, Job^, Cycle^]: The entity
-        matching the corresponding identifier. None if no entity is found.
+        The entity matching the corresponding identifier. None if no entity is found.
     Raises:
         ModelNotFound^: If _entity_id_ does not match a correct entity pattern.
     """
@@ -115,7 +121,7 @@ def get_tasks() -> List[Task]:
     """Return the list of all existing tasks.
 
     Returns:
-        List[Task^]: The list of tasks.
+        The list of tasks.
     """
     return _TaskManagerFactory._build_manager()._get_all()
 
@@ -128,7 +134,8 @@ def delete(entity_id: Union[TaskId, DataNodeId, PipelineId, ScenarioId, JobId, C
 
     - If a `CycleId^` is provided, the nested scenarios, pipelines, data nodes, and jobs are deleted.
     - If a `ScenarioId^` is provided, the nested pipelines, tasks, data nodes, and jobs are deleted.
-    If the scenario is primary, it can only be deleted if it is the only scenario in the cycle. In that case, its cycle is also deleted.
+    - If the scenario is primary, it can only be deleted if it is the only scenario in the cycle. In that case, its
+        cycle is also deleted.
     - If a `PipelineId^` is provided, the nested tasks, data nodes, and jobs are deleted.
     - If a `TaskId^` is provided, the nested data nodes, and jobs are deleted.
 
@@ -164,7 +171,7 @@ def get_scenarios(cycle: Optional[Cycle] = None, tag: Optional[str] = None) -> L
          cycle (Optional[Cycle^]): Cycle of the scenarios to return.
          tag (Optional[str]): Tag of the scenarios to return.
     Returns:
-        List[Scenario^]: The list of scenarios filtered by cycle or tag.
+        The list of scenarios filtered by cycle or tag.
     """
     if not cycle and not tag:
         return _ScenarioManagerFactory._build_manager()._get_all()
@@ -184,8 +191,8 @@ def get_primary(cycle: Cycle) -> Optional[Scenario]:
     Parameters:
          cycle (Cycle^): The cycle of the primary scenario to return.
     Returns:
-        Optional[Scenario^]: The primary scenario of the cycle _cycle_.
-            If the cycle has no primary scenario, this method returns None.
+        The primary scenario of the cycle _cycle_. If the cycle has no
+            primary scenario, this method returns None.
     """
     return _ScenarioManagerFactory._build_manager()._get_primary(cycle)
 
@@ -194,7 +201,7 @@ def get_primary_scenarios() -> List[Scenario]:
     """Return the list of all primary scenarios.
 
     Returns:
-        List[Scenario^]: The list of all primary scenarios.
+        The list of all primary scenarios.
     """
     return _ScenarioManagerFactory._build_manager()._get_primary_scenarios()
 
@@ -247,8 +254,7 @@ def compare_scenarios(*scenarios: Scenario, data_node_config_id: Optional[str] =
             if _datanode_config_id_ is None, the scenarios are compared based on all the defined
             comparators.
     Returns:
-        Dict[str, Any]: The comparison results. The key is the data node config identifier
-            that is compared.
+        The comparison results. The key is the data node config identifier that is compared.
     Raises:
         InsufficientScenarioToCompare^: Only one or no scenario for comparison is provided.
         NonExistingComparator^: The scenario comparator does not exist.
@@ -340,7 +346,7 @@ def get_pipelines() -> List[Pipeline]:
     """Return all existing pipelines.
 
     Returns:
-        List[Pipeline^]: The list of all pipelines.
+        The list of all pipelines.
     """
     return _PipelineManagerFactory._build_manager()._get_all()
 
@@ -349,7 +355,7 @@ def get_jobs() -> List[Job]:
     """Return all the existing jobs.
 
     Returns:
-        List[Job^]: The list of all jobs.
+        The list of all jobs.
     """
     return _JobManagerFactory._build_manager()._get_all()
 
@@ -387,8 +393,7 @@ def get_latest_job(task: Task) -> Optional[Job]:
     Parameters:
         task (Task^): The task to retrieve the latest job from.
     Returns:
-        Optional[Job^]: The latest job created from _task_. This is None if no job has been
-            created from _task_.
+        The latest job created from _task_. This is None if no job has been created from _task_.
     """
     return _JobManagerFactory._build_manager()._get_latest(task)
 
@@ -397,7 +402,7 @@ def get_data_nodes() -> List[DataNode]:
     """Return all the existing data nodes.
 
     Returns:
-        List[DataNode^]: The list of all data nodes.
+        The list of all data nodes.
     """
     return _DataManagerFactory._build_manager()._get_all()
 
@@ -406,7 +411,7 @@ def get_cycles() -> List[Cycle]:
     """Return the list of all existing cycles.
 
     Returns:
-        List[Cycle^]: The list of all cycles.
+        The list of all cycles.
     """
     return _CycleManagerFactory._build_manager()._get_all()
 
@@ -427,7 +432,7 @@ def create_scenario(
             If None, the current date time is used.
         name (Optional[str]): The displayable name of the scenario.
     Returns:
-        Scenario^: The new scenario.
+        The new scenario.
     """
     return _ScenarioManagerFactory._build_manager()._create(config, creation_date, name)
 
@@ -438,7 +443,7 @@ def create_pipeline(config: PipelineConfig) -> Pipeline:
     Parameters:
         config (PipelineConfig^): The pipeline configuration.
     Returns:
-        Pipeline^: The new pipeline.
+        The new pipeline.
     """
     return _PipelineManagerFactory._build_manager()._get_or_create(config)
 
@@ -450,7 +455,7 @@ def clean_all_entities() -> bool:
         Invoking this function is only recommended for development purposes.
 
     Returns:
-        bool: True if the operation succeeded, False otherwise.
+        True if the operation succeeded, False otherwise.
     """
     if not Config.global_config.clean_entities_enabled:
         __logger.warning("Please set 'clean_entities_enabled' to True to clean all entities.")
@@ -462,4 +467,114 @@ def clean_all_entities() -> bool:
     _ScenarioManagerFactory._build_manager()._delete_all()
     _CycleManagerFactory._build_manager()._delete_all()
     _JobManagerFactory._build_manager()._delete_all()
+    _VersionManagerFactory._build_manager()._delete_all()
     return True
+
+
+def clean_all_entities_by_version(version_number):
+    """Delete all entities belongs to a version from the Taipy data folder."""
+    version_manager = _VersionManagerFactory._build_manager()
+    try:
+        version_number = version_manager._replace_version_number(version_number)
+    except NonExistingVersion as e:
+        raise SystemExit(e.message)
+
+    _JobManagerFactory._build_manager()._delete_by_version(version_number)
+    _ScenarioManagerFactory._build_manager()._delete_by_version(version_number)
+    _PipelineManagerFactory._build_manager()._delete_by_version(version_number)
+    _TaskManagerFactory._build_manager()._delete_by_version(version_number)
+    _DataManagerFactory._build_manager()._delete_by_version(version_number)
+
+    version_manager._delete(version_number)
+    try:
+        version_manager._delete_production_version(version_number)
+    except VersionIsNotProductionVersion:
+        pass
+
+
+def export_scenario(
+    scenario_id: ScenarioId,
+    folder_path: Union[str, pathlib.Path],
+):
+    """Export all related entities of a scenario to a folder.
+
+    Parameters:
+        scenario_id (ScenarioId): The id of the scenario to export.
+        folder_path (Union[str, pathlib.Path]): The folder path to export the scenario to.
+    """
+
+    manager = _ScenarioManagerFactory._build_manager()
+    scenario = manager._get(scenario_id)
+    entity_ids = manager._get_children_entity_ids(scenario)  # type: ignore
+    entity_ids.scenario_ids = {scenario_id}
+    entity_ids.cycle_ids = {scenario.cycle.id}
+
+    shutil.rmtree(folder_path, ignore_errors=True)
+
+    for data_node_id in entity_ids.data_node_ids:
+        _DataManagerFactory._build_manager()._export(data_node_id, folder_path)
+    for task_id in entity_ids.task_ids:
+        _TaskManagerFactory._build_manager()._export(task_id, folder_path)
+    for pipeline_id in entity_ids.pipeline_ids:
+        _PipelineManagerFactory._build_manager()._export(pipeline_id, folder_path)
+    for cycle_id in entity_ids.cycle_ids:
+        _CycleManagerFactory._build_manager()._export(cycle_id, folder_path)
+    for scenario_id in entity_ids.scenario_ids:
+        _ScenarioManagerFactory._build_manager()._export(scenario_id, folder_path)
+    for job_id in entity_ids.job_ids:
+        _JobManagerFactory._build_manager()._export(job_id, folder_path)
+
+
+def get_parents(
+    entity: Union[TaskId, DataNodeId, PipelineId, Task, DataNode, Pipeline], parent_dict=None
+) -> Dict[str, Set[_Entity]]:
+    """Get the parents of an entity from itself or its identifier.
+
+    Parameters:
+        entity (Union[TaskId^, DataNodeId^, PipelineId^, Task, DataNode, Pipeline]): The entity or its
+            identifier to get the parents.<br/>
+    Returns:
+        The dictionary of all parent entities.
+            They are grouped by their type (Scenario^, Pipelines^, or tasks^) so each key corresponds
+            to a level of the parents and the value is a set of the parent entities.
+            An empty dictionary is returned if the entity does not have parents.<br/>
+            Example: The following instruction returns all the pipelines that include the
+            datanode identified by "my_datanode_id".
+            `taipy.get_parents("id_of_my_datanode")["pipelines"]`
+    Raises:
+        ModelNotFound^: If _entity_ does not match a correct entity pattern.
+    """
+
+    def update_parent_dict(parents_set, parent_dict, key):
+        if key in parent_dict.keys():
+            parent_dict[key].update(parents_set)
+        else:
+            parent_dict[key] = parents_set
+
+    if isinstance(entity, str):
+        entity = get(entity)  # type: ignore
+
+    parent_dict = parent_dict or dict()
+
+    if isinstance(entity, (Scenario, Cycle)):
+        return parent_dict
+
+    parents = {get(parent) for parent in entity.parent_ids}  # type: ignore
+
+    if isinstance(entity, Pipeline):
+        parent_entity_key = "scenarios"
+        update_parent_dict(parents, parent_dict, parent_entity_key)
+
+    if isinstance(entity, Task):
+        parent_entity_key = "pipelines"
+        update_parent_dict(parents, parent_dict, parent_entity_key)
+        for parent in parent_dict[parent_entity_key]:
+            get_parents(parent, parent_dict)
+
+    if isinstance(entity, DataNode):
+        parent_entity_key = "tasks"
+        update_parent_dict(parents, parent_dict, parent_entity_key)
+        for parent in parent_dict[parent_entity_key]:
+            get_parents(parent, parent_dict)
+
+    return parent_dict
